@@ -4,58 +4,59 @@ use warnings;
 
 package IO::Prompt::Tiny;
 # ABSTRACT: Prompt for user input with a default option
-our $VERSION = '0.002'; # VERSION
+
+our $VERSION = '0.003';
 
 use Exporter ();
-use Carp ();
-our @ISA = qw/Exporter/;
+use Carp     ();
+our @ISA       = qw/Exporter/;
 our @EXPORT_OK = qw/prompt/;
 
 # Copied from ExtUtils::MakeMaker (by many authors)
 sub prompt {
-  my($mess, $def) = @_;
-  Carp::croak("prompt function called without an argument") 
-    unless defined $mess;
+    my ( $mess, $def ) = @_;
+    Carp::croak("prompt function called without an argument")
+      unless defined $mess;
 
-  my $dispdef = defined $def ? "[$def] " : " ";
-  $def = defined $def ? $def : "";
+    my $dispdef = defined $def ? "[$def] " : " ";
+    $def = defined $def ? $def : "";
 
-  local $|=1;
-  local $\;
-  print "$mess $dispdef";
+    local $| = 1;
+    local $\;
+    print "$mess $dispdef";
 
-  my $ans;
-  if ($ENV{PERL_MM_USE_DEFAULT} || ! _is_interactive()) {
-    print "$def\n";
-  }
-  else {
-    $ans = <STDIN>;
-    if( defined $ans ) {
-      chomp $ans;
+    my $ans;
+    if ( $ENV{PERL_MM_USE_DEFAULT} || !_is_interactive() ) {
+        print "$def\n";
     }
-    else { # user hit ctrl-D
-      print "\n";
+    else {
+        $ans = <STDIN>;
+        if ( defined $ans ) {
+            chomp $ans;
+        }
+        else { # user hit ctrl-D
+            print "\n";
+        }
     }
-  }
 
-  return (!defined $ans || $ans eq '') ? $def : $ans;
+    return ( !defined $ans || $ans eq '' ) ? $def : $ans;
 }
 
 # Copied (without comments) from IO::Interactive::Tiny by Daniel Muey,
 # based on IO::Interactive by Damian Conway and brian d foy
 sub _is_interactive {
-  my ($out_handle) = (@_, select);
-  return 0 if not -t $out_handle;
-  if ( tied(*ARGV) or defined(fileno(ARGV)) ) {
-    return -t *STDIN if defined $ARGV && $ARGV eq '-';
-    return @ARGV>0 && $ARGV[0] eq '-' && -t *STDIN if eof *ARGV;
-    return -t *ARGV;
-  }
-  else {
-    return -t *STDIN;
-  }
+    my ($out_handle) = ( @_, select );
+    return 0 if not -t $out_handle;
+    if ( tied(*ARGV) or defined( fileno(ARGV) ) ) {
+        return -t *STDIN if defined $ARGV && $ARGV eq '-';
+        return @ARGV > 0 && $ARGV[0] eq '-' && -t *STDIN if eof *ARGV;
+        return -t *ARGV;
+    }
+    else {
+        return -t *STDIN;
+    }
 }
- 
+
 1;
 
 
@@ -65,7 +66,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -73,7 +74,7 @@ IO::Prompt::Tiny - Prompt for user input with a default option
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -160,7 +161,7 @@ L<Term::Prompt>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/dagolden/io-prompt-tiny/issues>.
+at L<https://github.com/dagolden/IO-Prompt-Tiny/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -168,9 +169,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/dagolden/io-prompt-tiny>
+L<https://github.com/dagolden/IO-Prompt-Tiny>
 
-  git clone git://github.com/dagolden/io-prompt-tiny.git
+  git clone https://github.com/dagolden/IO-Prompt-Tiny.git
 
 =head1 AUTHOR
 
